@@ -3,7 +3,7 @@
 ** distribution information.
 */
 
-/* $Id: acconfig.h,v 1.7 2000/10/05 04:15:41 mrsam Exp $ */
+/* $Id: acconfig.h,v 1.8 2001/02/09 13:23:35 mrsam Exp $ */
 
 /* Whether we must provide a prototype for crypt() */
 #undef	NEED_CRYPT_PROTOTYPE
@@ -25,3 +25,6 @@
 
 /* This macro is used to build the list of SASL modules */
 #undef	SASL_LIST
+
+/* Whether -lvpopmail has the open_smtp_relay() function */
+#undef HAVE_OPEN_SMTP_RELAY
