@@ -87,7 +87,7 @@ authldap_free_config removed - no longer required.
 #endif
 #if HAVE_LDAP_H
 #include <ldap.h>
-#if LDAP_VENDOR_VERSION > 0x20000
+#if LDAP_VENDOR_VERSION > 20000
 #define OPENLDAPV2
 #endif
 #endif
@@ -123,7 +123,7 @@ struct ldap_info
 	int   timeout;
 	int   authbind;
 
-	int	authbind_ok;
+	int	authbind_ok;  /* not used? */
 };
 
 /*
@@ -297,7 +297,7 @@ static int authldap_read_config(struct ldap_info *ldap)
     return 0;
   if (!read_env("LDAP_MAIL",&ldap->mail,"You need to specify a attribute for mail in config file",0,"mail"))
     return 0;
-  if (!read_env("LDAP_DOMAIN",&ldap->domain,"You need to specify a domain for mail in config file",0,"*"))
+  if (!read_env("LDAP_DOMAIN",&ldap->domain,"You need to specify a domain for mail in config file",0,""))
     return 0;
 
   p=0;
@@ -401,7 +401,7 @@ static void copy_value(LDAP *ld, LDAPMessage *entry, const char *attribut,
 	 {
 		 *copy=strdup(values[0]);
 	 }
-#ifdef DEBUG_LDAP
+#if DEBUG_LDAP
   syslog(LOG_DAEMON|LOG_CRIT,"copy_value %s: %s\n",attribut,values[0]);
 #endif
   ldap_value_free(values);
@@ -558,7 +558,7 @@ char *quota=0;
   }
 
   strcat(strcat(strcat(strcpy(filter, "("), my_ldap.mail), "="), user);
-  if ( strchr(user, '@') == 0)
+  if ( my_ldap.domain && my_ldap.domain[0] && strchr(user, '@') == 0 )
      strcat(strcat(filter, "@"), my_ldap.domain);
   strcat(filter, ")");
 
@@ -654,7 +654,7 @@ char *quota=0;
 	if (sscanf(p, "%lu", &n) > 0)
 		au= (uid_t)n;
 	free(p);
-#ifdef DEBUG_LDAP
+#if DEBUG_LDAP
 	syslog(LOG_DAEMON|LOG_CRIT,"au= %d\n",au);
 #endif
   }
@@ -670,7 +670,7 @@ char *quota=0;
 	if (sscanf(p, "%lu", &n) > 0)
 		ag= (gid_t)n;
 	free(p);
-#ifdef DEBUG_LDAP
+#if DEBUG_LDAP
 	syslog(LOG_DAEMON|LOG_CRIT,"ag= %d\n",ag);
 #endif
   }
@@ -706,11 +706,16 @@ char *quota=0;
 				rc=1;
 			else
 			{
-				if (ldaperror(
-				ldap_simple_bind_s(bindp, dn, (char *)pass)
-					!= LDAP_SUCCESS))
+				switch (ldap_simple_bind_s(bindp, dn, (char *)pass))
 				{
-					rc= my_ldap_fp ? 1:-1;
+				case LDAP_SUCCESS:
+					break;
+				case LDAP_INVALID_CREDENTIALS:
+					rc = -1;
+					break;
+				default:
+					rc = 1;
+					break;
 				}
 				ldap_unbind(bindp);
 			}
@@ -735,13 +740,13 @@ char *quota=0;
 		}
         }
 	free (dn);
-#ifdef DEBUG_LDAP
+#if DEBUG_LDAP
 	syslog(LOG_DAEMON|LOG_CRIT,"before callback rc=%d\n",rc);
 #endif
 
 	if (rc == 0)
 		rc= (*callback)(&auth, arg);
-#ifdef DEBUG_LDAP
+#if DEBUG_LDAP
 	syslog(LOG_DAEMON|LOG_CRIT,"after callback rc=%d\n",rc);
 #endif
 
