@@ -78,6 +78,10 @@ const	char *server;
 const	char *userid;
 const	char *password;
 const	char *database;
+const	char *server_socket=0;
+unsigned int server_port=0;
+unsigned int server_opt=0;
+const	char *p;
 
 	if (mysql)	return (0);
 
@@ -86,6 +90,18 @@ const	char *database;
 	password=read_env("MYSQL_PASSWORD");
 	database=read_env("MYSQL_DATABASE");
 
+	server_socket=(char *) read_env("MYSQL_SOCKET");
+
+	if ((p=read_env("MYSQL_PORT")) != 0)
+	{
+		server_port=(unsigned int) atoi(p);
+	}
+
+	if ((p=read_env("MYSQL_OPT")) != 0)
+	{
+		server_opt=(unsigned int) atol(p);
+	}
+
 	if (!server)
 	{
 		fprintf(stderr, "authmysql: MYSQL_SERVER not set in "
@@ -107,7 +123,16 @@ const	char *database;
 		return (-1);
 	}
 
+#if MYSQL_VERSION_ID >= 32200
+	mysql_init(&mysql_buf);
+	mysql=mysql_real_connect(&mysql_buf, server, userid, password,
+				 NULL,
+				 server_port,
+				 server_socket,
+				 server_opt);
+#else
 	mysql=mysql_connect(&mysql_buf, server, userid, password);
+#endif
 	if (!mysql)	return (-1);
 
 	if (mysql_select_db(mysql, database))
