@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 1999 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2000 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
@@ -17,8 +17,9 @@
 
 #include	"auth.h"
 #include	"authmod.h"
+#include	"authstaticlist.h"
 
-static const char rcsid[]="$Id: authpwd.c,v 1.7 2000/04/30 01:04:09 mrsam Exp $";
+static const char rcsid[]="$Id: authpwd.c,v 1.9 2000/10/14 17:34:44 mrsam Exp $";
 
 extern int auth_pwd_pre(const char *userid, const char *service,
         int (*callback)(struct authinfo *, void *),
@@ -98,3 +99,18 @@ int	rc;
 	}
 	return (ci.userret);
 }
+
+static void auth_pwd_cleanup()
+{
+#if	HAVE_ENDPWENT
+
+	endpwent();
+#endif
+}
+
+struct authstaticinfo authpwd_info={
+	"authpwd",
+	auth_pwd,
+	auth_pwd_pre,
+	auth_pwd_cleanup,
+	0};
