@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 1999 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2000 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
@@ -14,7 +14,7 @@
 #include	<unistd.h>
 #endif
 
-static const char rcsid[]="$Id: authtest.c,v 1.6 2000/05/29 21:01:30 mrsam Exp $";
+static const char rcsid[]="$Id: authtest.c,v 1.7 2000/10/05 04:15:41 mrsam Exp $";
 
 static void usage()
 {
@@ -84,12 +84,13 @@ char	*p;
 	if (argc - argn <= 0)
 		usage();
 
-	for (i=0; authstaticlist[i].auth_name; i++)
+	for (i=0; authstaticmodulelist[i]; i++)
 	{
 	char	*authdata;
 	char	buf[1024];
 
-		if (*module && strcmp(module, authstaticlist[i].auth_name))
+		if (*module && strcmp(module,
+				      authstaticmodulelist[i]->auth_name))
 			continue;
 
 		if (argc - argn > 1)
@@ -103,7 +104,7 @@ char	*p;
 			sprintf(authdata, "%s\n%s\n",
 				argv[argn], argv[argn+1]);
 
-			p= (*authstaticlist[i].auth_func)(service,
+			p= (*authstaticmodulelist[i]->auth_func)(service,
 				AUTHTYPE_LOGIN, authdata, 0, 0, 0);
 			free(authdata);
 			if (p == 0)	continue;
@@ -112,23 +113,24 @@ char	*p;
 		{
 		int	rc;
 
-			if ((rc=(*authstaticlist[i].auth_prefunc)(argv[argn],
-				service ? service:"",
+			if ((rc=(*authstaticmodulelist[i]->auth_prefunc)
+			     (argv[argn], service ? service:"",
 				&callback_pre, 0)) != 0)
 			{
-				(*authstaticlist[i].auth_cleanupfunc)();
+				(*authstaticmodulelist[i]->auth_cleanupfunc)();
 				if (rc < 0)
 					continue;
 				fprintf(stderr,
 					"Temporary authentication failure from "
 					"module %s\n",
-					authstaticlist[i].auth_name);
+					authstaticmodulelist[i]->auth_name);
 				break;
 			}
-			(*authstaticlist[i].auth_cleanupfunc)();
+			(*authstaticmodulelist[i]->auth_cleanupfunc)();
 		}
 
-		printf("Authenticated: module %s\n", authstaticlist[i].auth_name);
+		printf("Authenticated: module %s\n",
+		       authstaticmodulelist[i]->auth_name);
 		if ( getcwd(buf, sizeof(buf)))
 			printf("Home directory: %s\n", buf);
 		else
