@@ -25,7 +25,7 @@ extern char *authvchkpw_isvirtual(char *);
 extern FILE *authvchkpw_file(const char *, const char *);
 extern struct passwd *authvchkpw_search(FILE *, const char *);
 
-static const char rcsid[]="$Id: preauthvchkpw.c,v 1.11 2000/10/06 23:45:17 mrsam Exp $";
+static const char rcsid[]="$Id: preauthvchkpw.c,v 1.13 2001/02/09 13:23:35 mrsam Exp $";
 
 int auth_vchkpw_pre(const char *userid, const char *service,
         int (*callback)(struct authinfo *, void *),
@@ -75,6 +75,20 @@ struct authinfo auth;
 		return (-1);
 	}
 
+	if ( strcmp("webmail", service) == 0 && pw->pw_gid & NO_WEBMAIL ) 
+		return(-1);
+
+	if ( strcmp("imap", service) == 0 ) {
+		if ( pw->pw_gid & NO_IMAP ) {
+			return(-1);
+		} else {
+#ifdef HAVE_OPEN_SMTP_RELAY
+			/* open the relay to imap users */
+			open_smtp_relay();
+#endif
+		}
+	}
+
 	pw->pw_uid=uid;
 	pw->pw_gid=gid;
 
