@@ -14,7 +14,7 @@
 #endif
 #include	"imapwrite.h"
 
-static const char rcsid[]="$Id: capability.c,v 1.3 2000/07/23 02:45:48 mrsam Exp $";
+static const char rcsid[]="$Id: capability.c,v 1.4 2000/11/11 19:52:31 mrsam Exp $";
 
 int have_starttls()
 {
@@ -44,7 +44,11 @@ void capability()
 const char *p;
 
 	writes("* CAPABILITY ");
-	if ((p=getenv("IMAP_CAPABILITY")) != 0 && *p)
+
+	if ((p=getenv("IMAP_TLS")) && atoi(p) &&
+	    (p=getenv("IMAP_CAPABILITY_TLS")) && *p)
+		writes(p);
+	else if ((p=getenv("IMAP_CAPABILITY")) != 0 && *p)
 		writes(p);
 	else
 		writes("IMAP4rev1");
