@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2000 Double Precision, Inc.
+** Copyright 1998 - 2001 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -27,7 +27,9 @@
 #include	"maildir/maildirgetquota.h"
 #include	"maildir/maildirquota.h"
 
-static const char rcsid[]="$Id: fetch.c,v 1.13 2000/11/15 17:52:21 mrsam Exp $";
+static const char rcsid[]="$Id: fetch.c,v 1.15 2001/02/20 12:53:52 mrsam Exp $";
+
+unsigned long header_count=0, body_count=0;	/* Total transferred */
 
 extern int current_mailbox_ro;
 extern struct imapscaninfo current_mailbox_info;
@@ -807,6 +809,8 @@ off_t cache_phys_chars;
 			--skipping;
 		else
 		{
+			++body_count;
+
 			if (bufptr >= sizeof(buf))
 			{
 				writemem(buf, sizeof(buf));
@@ -1000,6 +1004,7 @@ int	ii;
 		writemem(p, i);
 		p += i;
 		cnt -= i;
+		header_count += i;
 	}
 }
 
@@ -1143,6 +1148,8 @@ static void countheader(struct fetchheaderinfo *fi, const char *p, size_t s)
 
 static void printheader(struct fetchheaderinfo *fi, const char *p, size_t s)
 {
+	size_t i;
+
 	if (fi->skipping)
 	{
 		if (fi->skipping > s)
@@ -1155,6 +1162,9 @@ static void printheader(struct fetchheaderinfo *fi, const char *p, size_t s)
 		fi->skipping=0;
 	}
 	if (s > fi->cnt)	s=fi->cnt;
+	for (i=0; i <= s; i++)
+		if (p[i] != '\r')
+			++header_count;
 	writemem(p, s);
 	fi->cnt -= s;
 }
@@ -1214,6 +1224,7 @@ unsigned long i;
 		}
 		buf[i++]=c;
 		--n;
+		++body_count;
 	}
 	writemem(buf, i);
 }
@@ -1283,6 +1294,7 @@ int	eol;
 		}
 		buf[i++]=c;
 		--n;
+		++header_count;
 	}
 	writemem(buf, i);
 }
@@ -1341,6 +1353,7 @@ unsigned l;
 			}
 		}
 		buf[l++]=c;
+		++body_count;
 	}
 	writemem(buf, l);
 }
