@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2000 Double Precision, Inc.
+** Copyright 1998 - 2001 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -44,6 +44,9 @@
 #include	<time.h>
 #endif
 #endif
+#if HAVE_LOCALE_H
+#include	<locale.h>
+#endif
 
 #include	<sys/types.h>
 #include	<sys/stat.h>
@@ -72,10 +75,11 @@
 
 #define	SHARED	"shared"
 
-static const char rcsid[]="$Id: imapd.c,v 1.50 2000/11/15 17:52:21 mrsam Exp $";
+static const char rcsid[]="$Id: imapd.c,v 1.56 2001/02/22 01:04:01 mrsam Exp $";
 
 extern time_t rfc822_parsedt(const char *);
 extern void fetchflags(unsigned long);
+extern unsigned long header_count, body_count;
 
 extern int do_fetch(unsigned long, int, void *);
 extern int do_copy(unsigned long, int, void *);
@@ -938,6 +942,28 @@ char	*p=malloc(strlen(mbox)+strlen(name)+sizeof("/cur/"));
 
 /****************************************************************************/
 
+/* Do the IDLE stuff                                                        */
+
+/****************************************************************************/
+
+extern int doidle(time_t);
+
+static void idle(void)
+{
+const char * envp = getenv("IMAP_IDLE_TIMEOUT");
+const int idleTimeout = envp ? atoi(envp) : 60;
+
+       writes("+ entering idle mode\r\n");
+       writeflush();
+       while (!doidle(idleTimeout))
+       {
+               noop();
+               writeflush();
+       }
+}
+
+/****************************************************************************/
+
 /* Do the EXPUNGE stuff                                                     */
 
 /****************************************************************************/
@@ -1100,6 +1126,110 @@ FILE *oldfp;
 	free(newf);
 }
 
+// Hierarchical rename
+
+static int chk_rename(const char *, const char *);
+static int do_rename(const char *, const char *);
+
+static int scan_hier_rename(const char *, const char *,
+			    int (*)(const char *, const char *), int);
+
+static int hier_rename(const char *oldname, const char *newname, int ishier)
+{
+	if (scan_hier_rename(oldname, newname, chk_rename, ishier))
+		return (-1);
+
+	scan_hier_rename(oldname, newname, do_rename, ishier);
+	return (0);
+}
+
+static int scan_hier_rename(const char *oldname,
+			    const char *newname,
+			    int (*func)(const char *, const char *),
+			    int ishier)
+{
+	int oldname_l=strlen(oldname);
+	DIR *dirp;
+	struct dirent *de;
+
+	dirp=opendir(".");
+	while (dirp && (de=readdir(dirp)) != 0)
+	{
+		char *tst_cur;
+
+		if (de->d_name[0] != '.')
+			continue;
+		if (strcmp(de->d_name, "..") == 0)
+			continue;
+
+		if ((tst_cur=malloc(strlen(de->d_name)+sizeof("/cur")))
+		    == NULL)
+		{
+			write_error_exit(0);
+		}
+		strcat(strcpy(tst_cur, de->d_name), "/cur");
+		if (access(tst_cur, 0))
+		{
+			free(tst_cur);
+			continue;
+		}
+		free(tst_cur);
+		if (strncmp(de->d_name, oldname, oldname_l))
+			continue;
+
+		if (de->d_name[oldname_l] == 0)
+		{
+			if (ishier)
+				continue;	// Only the hierarchy
+
+			if ( (*func)(oldname, newname))
+			{
+				closedir(dirp);
+				return (-1);
+			}
+			continue;
+		}
+
+	        if (de->d_name[oldname_l] != HIERCH)
+			continue;
+
+		if (!ishier)
+			continue;
+
+		tst_cur=malloc(strlen(newname) + strlen(de->d_name+oldname_l)
+			       + 1);
+		if (!tst_cur)
+			write_error_exit(0);
+
+		strcat(strcpy(tst_cur, newname), de->d_name+oldname_l);
+
+		if ( (*func)(de->d_name, tst_cur))
+		{
+			free(tst_cur);
+			closedir(dirp);
+			return (-1);
+		}
+		free(tst_cur);
+	}
+	closedir(dirp);
+	return (0);
+}
+
+static int chk_rename(const char *on, const char *nn)
+{
+	if (access(nn, 0) == 0)
+		return (-1);	// Destination folder exists
+	return (0);
+}
+
+static int do_rename(const char *on, const char *nn)
+{
+	rename(on, nn);
+	return (0);
+}
+
+static int do_rename(const char *, const char *);
+
 int do_imap_command(const char *tag)
 {
 struct	imaptoken *curtoken=nexttoken();
@@ -1126,6 +1256,25 @@ int	uid=0;
 		writes(" OK NOOP completed\r\n");
 		return (0);
 	}
+       if (strcmp(curtoken->tokenbuf, "IDLE") == 0)
+       {
+               if (nexttoken()->tokentype != IT_EOL)   return (-1);
+               if (current_mailbox)
+               {
+                       read_eol();
+                       idle();
+                       curtoken=nexttoken();
+                       if (strcmp(curtoken->tokenbuf, "DONE") == 0)
+                       {
+                               if (current_mailbox)
+                                       noop();
+                               writes(tag);
+                               writes(" OK IDLE completed\r\n");
+                               return (0);
+                       }
+               }
+               return (-1);
+       }
 	if (strcmp(curtoken->tokenbuf, "LOGOUT") == 0)
 	{
 		if (nexttoken()->tokentype != IT_EOL)	return (-1);
@@ -1135,8 +1284,10 @@ int	uid=0;
 		writes(" OK LOGOUT completed\r\n");
 		writeflush();
 		emptytrash();
-		fprintf(stderr, "INFO: LOGOUT, user=%s, ip=[%s]\n",
-			getenv("AUTHENTICATED"), getenv("TCPREMOTEIP"));
+		fprintf(stderr, "INFO: LOGOUT, user=%s, ip=[%s],"
+			" headers=%lu, body=%lu\n",
+			getenv("AUTHENTICATED"), getenv("TCPREMOTEIP"),
+			header_count, body_count);
 		exit(0);
 	}
 
@@ -1577,9 +1728,27 @@ int	uid=0;
 	if (strcmp(curtoken->tokenbuf, "RENAME") == 0)
 	{
 	char	*mailbox, *new_mailbox;
+	char	*p;
+	int	ishier=0;
 
 		curtoken=nexttoken_nouc();
-		mailbox=parse_mailbox_error(tag, curtoken, 0, 0);
+
+		if (curtoken->tokentype != IT_NUMBER &&
+		    curtoken->tokentype != IT_ATOM &&
+		    curtoken->tokentype != IT_QUOTED_STRING)
+		{
+			writes(tag);
+			writes(" NO Invalid mailbox\r\n");
+			return (0);
+		}
+
+		if ((p=strrchr(curtoken->tokenbuf, HIERCH))  && p[1] == 0)
+		{
+			ishier=1;
+			*p=0;
+		}
+
+		mailbox=valid_mailbox_name(curtoken->tokenbuf, 0);
 		if ( mailbox == 0)
 			return (0);
 		if (strncmp(curtoken->tokenbuf, SHARED HIERCHS,
@@ -1599,6 +1768,12 @@ int	uid=0;
 			free(mailbox);
 			return (-1);
 		}
+
+		if ((p=strrchr(curtoken->tokenbuf, HIERCH)) && p[1] == 0)
+		{
+			*p=0;
+		}
+
 		if ((new_mailbox=valid_mailbox_name(curtoken->tokenbuf, 0))
 			== 0)
 		{
@@ -1625,21 +1800,12 @@ int	uid=0;
 			return (-1);
 		}
 
-		if (access(new_mailbox, 0) == 0)
-		{
-			free(mailbox);
-			free(new_mailbox);
-			writes(tag);
-			writes(" NO Destination folder exists.\r\n");
-			return (0);
-		}
-
 		fetch_free_cache();
 		if (strcmp(mailbox, "."))
 		{
 			if (is_reserved(mailbox) ||
 				is_reserved(new_mailbox) ||
-				rename(mailbox, new_mailbox))
+				hier_rename(mailbox, new_mailbox, ishier))
 			{
 				free(mailbox);
 				free(new_mailbox);
@@ -1723,7 +1889,7 @@ int	uid=0;
 		mailboxmetrics();
 		writes("* OK [UIDVALIDITY ");
 		writen(current_mailbox_info.uidv);
-		writes("]\r\n");
+		writes("] Ok\r\n");
 		writes(tag);
 		writes(ro ? " OK [READ-ONLY] Ok\r\n":" OK [READ-WRITE] Ok\r\n");
 		return (0);
@@ -1888,7 +2054,8 @@ int	uid=0;
 		if (nexttoken()->tokentype != IT_EOL)
 			return (-1);
 
-		expunge();
+		if (!current_mailbox_ro)
+			expunge();
 		free(current_mailbox);
 		imapscan_free(&current_mailbox_info);
 		current_mailbox=0;
@@ -2531,6 +2698,10 @@ const char *tag;
 		putenv("AUTHENTICATED=user");
 	}
 
+#if HAVE_SETLOCALE
+	setlocale(LC_CTYPE, "C");
+#endif
+
 	ip=getenv("TCPREMOTEIP");
 	if (!ip || !*ip)	exit(0);
 
