@@ -17,7 +17,7 @@
 #include	"imaptoken.h"
 #include	"imapwrite.h"
 
-static const char rcsid[]="$Id: mainloop.c,v 1.3 2000/02/28 05:16:52 mrsam Exp $";
+static const char rcsid[]="$Id: mainloop.c,v 1.4 2001/02/26 05:16:21 mrsam Exp $";
 
 extern int do_imap_command(const char *);
 
@@ -34,6 +34,8 @@ static char byemsg[]="* BYE Courier-IMAP server shut down by signal.\r\n";
 
 void mainloop(void)
 {
+	int noerril = 0;
+
 	signal(SIGTERM, sigexit);
 	signal(SIGHUP, sigexit);
 	signal(SIGINT, sigexit);
@@ -56,12 +58,19 @@ void mainloop(void)
 
 			if (rc == 0)
 			{
+				noerril = 0;
 				writeflush();
 				read_eol();
 				continue;
 			}
 		}
 
+		noerril++;
+		if (noerril > 9)
+		{
+			errno = 0;
+			write_error_exit("TOO MANY CONSECUTIVE PROTOCOL VIOLATIONS");
+		}
 		read_eol();
 		writes(tag[0] ? tag:"*");
 		writes(" NO Error in IMAP command received by server.\r\n");
