@@ -14,7 +14,7 @@
 #include	<stdlib.h>
 #include	<string.h>
 
-static const char rcsid[]="$Id: msgbodystructure.c,v 1.9 2000/04/25 16:47:27 mrsam Exp $";
+static const char rcsid[]="$Id: msgbodystructure.c,v 1.11 2000/09/22 12:32:38 mrsam Exp $";
 
 extern void msgenvelope(void (*)(const char *, size_t),
 		FILE *, struct rfc2045 *);
@@ -131,7 +131,8 @@ char	*p, *q;
 
 	(*writefunc)("(", 1);
 
-	if (mimep->firstpart && mimep->firstpart->isdummy)
+	if (mimep->firstpart && mimep->firstpart->isdummy &&
+		mimep->firstpart->next)
 		/* MULTIPART */
 	{
 	struct rfc2045	*childp;
@@ -213,7 +214,8 @@ char	*p, *q;
 			(*writefunc)(buf, strlen(buf));
 		}
 
-		if (mimep->firstpart)	/* message/rfc822 */
+		if (mimep->firstpart && !mimep->firstpart->isdummy)
+			/* message/rfc822 */
 		{
 			(*writefunc)(" ", 1);
 			msgenvelope(writefunc, fp, mimep->firstpart);
