@@ -28,7 +28,7 @@
 #include	"imaptoken.h"
 #include	"imapscanclient.h"
 
-static const char rcsid[]="$Id: search.c,v 1.15 2000/11/14 05:15:31 mrsam Exp $";
+static const char rcsid[]="$Id: search.c,v 1.16 2000/11/27 01:43:53 mrsam Exp $";
 
 extern time_t rfc822_parsedt(const char *);
 extern struct imapscaninfo current_mailbox_info;
@@ -627,7 +627,7 @@ static void fill_search_header(struct searchinfo *si,
 			if (sip->type == search_cc && strcmp(p, "CC") == 0 &&
 				sip->as == 0)
 			{
-			struct rfc822t *t=rfc822t_alloc(q, 0);
+			struct rfc822t *t=rfc822t_alloc_new(q, NULL, NULL);
 			struct rfc822a *a=t ? rfc822a_alloc(t):0;
 
 				sip->as= a && a->naddrs > 0 ?
@@ -647,7 +647,7 @@ static void fill_search_header(struct searchinfo *si,
 			if (sip->type == search_from && strcmp(p, "FROM") == 0
 				&& sip->as == 0)
 			{
-			struct rfc822t *t=rfc822t_alloc(q, 0);
+			struct rfc822t *t=rfc822t_alloc_new(q, NULL, NULL);
 			struct rfc822a *a=t ? rfc822a_alloc(t):0;
 
 				sip->as= a && a->naddrs > 0 ?
@@ -659,7 +659,7 @@ static void fill_search_header(struct searchinfo *si,
 			if (sip->type == search_to && strcmp(p, "TO") == 0 &&
 				sip->as == 0)
 			{
-			struct rfc822t *t=rfc822t_alloc(q, 0);
+			struct rfc822t *t=rfc822t_alloc_new(q, NULL, NULL);
 			struct rfc822a *a=t ? rfc822a_alloc(t):0;
 
 				sip->as= a && a->naddrs > 0 ?
@@ -696,7 +696,7 @@ static void fill_search_header(struct searchinfo *si,
 				struct rfc822a *a;
 				char *s;
 
-				t=rfc822t_alloc(q, 0);
+				t=rfc822t_alloc_new(q, NULL, NULL);
 				if (!t) write_error_exit(0);
 				a=rfc822a_alloc(t);
 				if (!a) write_error_exit(0);
