@@ -12,7 +12,7 @@
 #include	<string.h>
 #include	<arpa/inet.h>
 
-static const char rcsid[]="$Id: testmxlookup.c,v 1.7 2000/05/28 17:46:00 mrsam Exp $";
+static const char rcsid[]="$Id: testmxlookup.c,v 1.8 2000/06/23 00:57:21 mrsam Exp $";
 
 static void setns(const char *p)
 {
@@ -74,7 +74,7 @@ struct rfc1035_mxlist *mxlist, *p;
 		exit(0);
 	}
 
-	printf("Domain %s, mail sent to:\n", q_name);
+	printf("Domain %s:\n", q_name);
 	for (p=mxlist; p; p=p->next)
 	{
 	RFC1035_ADDR	addr;
@@ -85,7 +85,7 @@ struct rfc1035_mxlist *mxlist, *p;
 			continue;
 		rfc1035_ntoa(&addr, buf);
 
-		printf("Host: %s, Priority: %d, Address: %s%s\n",
+		printf("Relay: %s, Priority: %d, Address: %s%s\n",
 			p->hostname, p->priority, buf,
 			strcmp(p->hostname, buf) ? "":" [ ERROR ]");
 	}
