@@ -15,6 +15,11 @@
 #if	HAVE_STRINGS_H
 #include	<strings.h>
 #endif
+
+#if	HAVE_LOCALE_H
+#include	<locale.h>
+#endif
+
 #include	<stdlib.h>
 #include	<ctype.h>
 #include	<pwd.h>
@@ -37,7 +42,7 @@ int gethostname(const char *, size_t);
 #endif
 
 
-static const char rcsid[]="$Id: reformime.c,v 1.32 2000/10/23 02:22:40 mrsam Exp $";
+static const char rcsid[]="$Id: reformime.c,v 1.33 2000/12/16 20:55:35 mrsam Exp $";
 
 void rfc2045_error(const char *errmsg)
 {
@@ -877,6 +882,10 @@ int	rwmode=0;
 void	(*do_extract)(struct rfc2045 *, const char *, int, char **)=0;
 const char *extract_filename=0;
 
+#if HAVE_SETLOCALE
+	setlocale(LC_ALL, "C");
+#endif
+
 	for (argn=1; argn<argc; )
 	{
 		if (argv[argn][0] != '-')	break;
