@@ -1,10 +1,10 @@
 /*
-** Copyright 1998 - 1999 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2000 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 /*
-** $Id: rfc2045.c,v 1.21 2000/08/05 21:56:07 mrsam Exp $
+** $Id: rfc2045.c,v 1.24 2000/12/30 20:46:59 mrsam Exp $
 */
 #if    HAVE_CONFIG_H
 #include       "config.h"
@@ -595,7 +595,11 @@ int	bit8=0;
 
 		if (!p->content_type ||
 			strncmp(p->content_type, "multipart/", 10))
-			rfc2045_setattr(&p->content_type_attr, "boundary", 0);
+		{
+			if (p->boundary)
+				free(p->boundary);
+			p->boundary=0;
+		}
 
 		/* If this section's a message, we will expect to see
 		** more RFC2045 stuff, so create a nested RFC2045 structure,
@@ -769,7 +773,7 @@ char	*t;
 
 	/* Parse the header line according to RFC822 */
 
-	header=rfc822t_alloc(p->header, NULL);
+	header=rfc822t_alloc_new(p->header, NULL, NULL);
 
 	if (!header)	return;	/* Broken header */
 
@@ -1010,7 +1014,7 @@ int	i;
 
 	if (!cb || !*cb)	return (0);
 
-	t=rfc822t_alloc(cb, 0);
+	t=rfc822t_alloc_new(cb, 0, NULL);
 	if (!t)
 	{
 		rfc2045_enomem();
@@ -1167,6 +1171,13 @@ const char *cb=rfc2045_getattr( p->content_type_attr, "boundary");
 	return (cb);
 }
 
+int rfc2045_isflowed(const struct rfc2045 *p)
+{
+	const char *cb=rfc2045_getattr(p->content_type_attr, "format");
+
+	return (cb && strcmp(cb, "flowed") == 0);
+}
+
 void rfc2045_dispositioninfo(const struct rfc2045 *p,
 	const char **disposition_s,
 	const char **disposition_name_s,
