@@ -4,7 +4,7 @@
 */
 
 /*
-** $Id: imaprefs.c,v 1.4 2000/11/14 05:15:31 mrsam Exp $
+** $Id: imaprefs.c,v 1.7 2001/01/14 21:03:57 mrsam Exp $
 */
 
 #include	"config.h"
@@ -386,7 +386,7 @@ struct imap_refmsg *rfc822_threadmsg(struct imap_refmsgtable *mt,
 
 	char *msgid_s;
 
-	t=rfc822t_alloc(msgidhdr ? msgidhdr:"", 0);
+	t=rfc822t_alloc_new(msgidhdr ? msgidhdr:"", NULL, NULL);
 	if (!t)
 		return (0);
 	a=rfc822a_alloc(t);
@@ -531,8 +531,56 @@ void rfc822_threadprune(struct imap_refmsgtable *mt)
 	}
 }
 
+static int cmp_msgs(const void *, const void *);
+
+int rfc822_threadsortsubj(struct imap_refmsg *root)
+{
+	struct imap_refmsg *toproot;
+
 /*
-** (4) Gather together messages under the root that have the same
+** (4) Sort the messages under the root (top-level siblings only)
+** by sent date.  In the case of an exact match on sent date or if
+** either of the Date: headers used in a comparison can not be
+** parsed, use the order in which the messages appear in the
+** mailbox (that is, by sequence number) to determine the order.
+** In the case of a dummy message, sort its children by sent date
+** and then use the first child for the top-level sort.
+*/
+	size_t cnt, i;
+	struct imap_refmsg **sortarray;
+
+	for (cnt=0, toproot=root->firstchild; toproot;
+	     toproot=toproot->nextsib)
+	{
+		if (toproot->isdummy)
+			rfc822_threadsortsubj(toproot);
+		++cnt;
+	}
+
+	if ((sortarray=malloc(sizeof(struct imap_refmsg *)*(cnt+1))) == 0)
+		return (-1);
+
+	for (cnt=0; (toproot=root->firstchild) != NULL; ++cnt)
+	{
+		sortarray[cnt]=toproot;
+		breakparent(toproot);
+	}
+
+	qsort(sortarray, cnt, sizeof(*sortarray), cmp_msgs);
+
+	for (i=0; i<cnt; i++)
+		linkparent(sortarray[i], root);
+	free(sortarray);
+	return (0);
+}
+
+int rfc822_threadgathersubj(struct imap_refmsgtable *mt,
+			    struct imap_refmsg *root)
+{
+	struct imap_refmsg *toproot, *p;
+
+/*
+** (5) Gather together messages under the root that have the same
 ** extracted subject text.
 **
 ** (A) Create a table for associating extracted subjects with
@@ -542,11 +590,6 @@ void rfc822_threadprune(struct imap_refmsgtable *mt)
 ** extracted subject.  For each message under the root:
 */
 
-int rfc822_threadsortsubj(struct imap_refmsgtable *mt,
-			  struct imap_refmsg *root)
-{
-	struct imap_refmsg *toproot, *p;
-
 	for (toproot=root->firstchild; toproot; toproot=toproot->nextsib)
 	{
 		const char *subj;
@@ -791,16 +834,17 @@ int rfc822_threadmergesubj(struct imap_refmsgtable *mt,
 }
 
 /*
-**
-** (5) Traverse the messages under the root and sort each set of
+** (6) Traverse the messages under the root and sort each set of
 ** siblings by sent date.  Traverse the messages in such a way
 ** that the "youngest" set of siblings are sorted first, and the
 ** "oldest" set of siblings are sorted last (grandchildren are
 ** sorted before children, etc).  In the case of an exact match on
-** sent date, use the order in which the messages appear in the
-** mailbox (that is, by sequence number) to determine the order.
-** In the case of a dummy message (which can only occur with top-
-** level siblings), use its first child for sorting.
+** sent date or if either of the Date: headers used in a
+** comparison can not be parsed, use the order in which the
+** messages appear in the mailbox (that is, by sequence number) to
+** determine the order.  In the case of a dummy message (which can
+** only occur with top-level siblings), use its first child for
+** sorting.
 */
 
 static int cmp_msgs(const void *a, const void *b)
@@ -829,7 +873,7 @@ static int cmp_msgs(const void *a, const void *b)
 		nb=mb->seqnum;
 	}
 
-	return (ta < tb ? -1: ta > tb ? 1:
+	return (ta && tb && ta != tb ? ta < tb ? -1: 1:
 		na < nb ? -1: na > nb ? 1:0);
 }
 
@@ -907,7 +951,8 @@ struct imap_refmsg *rfc822_thread(struct imap_refmsgtable *mt)
 		rfc822_threadprune(mt);
 		if ((mt->rootptr=rfc822_threadgetroot(mt)) == 0)
 			return (0);
-		if (rfc822_threadsortsubj(mt, mt->rootptr) ||
+		if (rfc822_threadsortsubj(mt->rootptr) ||
+		    rfc822_threadgathersubj(mt, mt->rootptr) ||
 		    rfc822_threadmergesubj(mt, mt->rootptr) ||
 		    rfc822_threadsortbydate(mt))
 		{
