@@ -4,7 +4,7 @@
 */
 
 /*
-** $Id: rfc822.c,v 1.13 2000/10/22 05:23:50 mrsam Exp $
+** $Id: rfc822.c,v 1.14 2000/11/25 23:51:41 mrsam Exp $
 */
 #include	<stdio.h>
 #include	<ctype.h>
@@ -13,7 +13,7 @@
 #include	"rfc822.h"
 
 static void tokenize(const char *p, struct rfc822token *tokp, int *toklen,
-	void (*err_func)(const char *, int))
+	void (*err_func)(const char *, int, void *), void *voidp)
 {
 const char *addr=p;
 int	i=0;
@@ -44,7 +44,8 @@ int	inbracket=0;
 			{
 				if (!*p)
 				{
-					if (err_func) (*err_func)(addr, i);
+					if (err_func) (*err_func)(addr, i,
+								  voidp);
 					if (tokp) tokp->token='"';
 					++*toklen;
 					return;
@@ -86,7 +87,8 @@ int	inbracket=0;
 			{
 				if (!*p)
 				{
-					if (err_func) (*err_func)(addr, i);
+					if (err_func) (*err_func)(addr, i,
+								  voidp);
 					++*toklen;
 					return;
 				}
@@ -107,7 +109,7 @@ int	inbracket=0;
 			continue;
 		case '\\':
 		case ')':
-			if (err_func) (*err_func)(addr, i);
+			if (err_func) (*err_func)(addr, i, voidp);
 			++p;
 			++i;
 			continue;
@@ -129,7 +131,7 @@ int	inbracket=0;
 			if ( (*p == '<' && inbracket) ||
 				(*p == '>' && !inbracket))
 			{
-				if (err_func) (*err_func)(addr, i);
+				if (err_func) (*err_func)(addr, i, voidp);
 				++p;
 				++i;
 				continue;
@@ -182,7 +184,7 @@ int	inbracket=0;
 			}
 			if (i == 0)	/* Idiot check */
 			{
-				if (err_func) (*err_func)(addr, i);
+				if (err_func) (*err_func)(addr, i, voidp);
 				if (tokp)
 				{
 					tokp->token='"';
@@ -599,15 +601,31 @@ int	i;
 	}
 }
 
+static void compat_err_func(const char *p, int i, void *voidp)
+{
+	void (*err_func)(const char *, int)=
+		(void (*)(const char *, int))voidp;
+
+	if (err_func)
+		(*err_func)(p, i);
+}
+
 struct rfc822t *rfc822t_alloc(const char *addr,
-	void (*err_func)(const char *, int))
+			      void (*err_func)(const char *, int))
+{
+	return (rfc822t_alloc_new(addr, &compat_err_func, err_func));
+}
+
+
+struct rfc822t *rfc822t_alloc_new(const char *addr,
+	void (*err_func)(const char *, int, void *), void *voidp)
 {
 struct rfc822t *p=(struct rfc822t *)malloc(sizeof(struct rfc822t));
 
 	if (!p)	return (NULL);
 	memset(p, 0, sizeof(*p));
 
-	tokenize(addr, NULL, &p->ntokens, err_func);
+	tokenize(addr, NULL, &p->ntokens, err_func, voidp);
 	p->tokens=p->ntokens ? (struct rfc822token *)
 			calloc(p->ntokens, sizeof(struct rfc822token)):0;
 	if (p->ntokens && !p->tokens)
@@ -615,7 +633,7 @@ struct rfc822t *p=(struct rfc822t *)malloc(sizeof(struct rfc822t));
 		rfc822t_free(p);
 		return (NULL);
 	}
-	tokenize(addr, p->tokens, &p->ntokens, NULL);
+	tokenize(addr, p->tokens, &p->ntokens, NULL, NULL);
 	return (p);
 }
 
