@@ -1,5 +1,5 @@
 /*
-** Copyright 2000 Double Precision, Inc.
+** Copyright 2000-2001 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 #include	"config.h"
@@ -26,7 +26,7 @@
 #include	<openssl/err.h>
 #include	<sys/time.h>
 
-static const char rcsid[]="$Id: starttls.c,v 1.7 2000/07/24 23:35:23 mrsam Exp $";
+static const char rcsid[]="$Id: starttls.c,v 1.9 2001/02/11 20:34:14 mrsam Exp $";
 
 #ifndef NO_RSA
 static RSA *rsa_callback(SSL *, int, int);
@@ -154,7 +154,7 @@ SSL_CTX *ctx;
 		}
 	}
 
-	if (peer_cert_dir && ourcacert)
+	if (peer_cert_dir || ourcacert)
 	{
 		if ((!SSL_CTX_set_default_verify_paths(ctx))
 			|| (!SSL_CTX_load_verify_locations(ctx, ourcacert,
