@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2000 Double Precision, Inc.
+** Copyright 1998 - 2001 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -55,7 +55,7 @@
 
 #include	<netdb.h>
 
-static const char rcsid[]="$Id: tcpd.c,v 1.19 2000/09/17 18:19:05 mrsam Exp $";
+static const char rcsid[]="$Id: tcpd.c,v 1.21 2001/01/24 05:30:14 mrsam Exp $";
 
 static const char *accessarg=0;
 static const char *listenarg=0;
@@ -73,6 +73,7 @@ static const char *pidarg=0;
 static const char *proxyarg=0;
 static const char *restartarg=0;
 static const char *stoparg=0;
+static const char *stderrloggername=0;
 
 static char *lockfilename;
 
@@ -93,6 +94,7 @@ static struct args arginfo[]={
 	{"restart", &restartarg},
 	{"stderr", &stderrarg},
 	{"stderrlogger", &stderrloggerarg},
+	{"stderrloggername", &stderrloggername},
 	{"stop", &stoparg},
 	{"user", &userarg},
 	{"proxy", &proxyarg},
@@ -475,8 +477,13 @@ int	lockfd;
 
 				if (p)	++p;
 				else p=progname;
+
+				if (stderrloggername && *stderrloggername)
+					p=stderrloggername;
+
 				execl(stderrloggerarg, stderrloggerarg,
 						p, (char *)0);
+				perror(stderrloggerarg);
 				_exit(5);
 			}
 			_exit(0);
@@ -952,11 +959,11 @@ char	buf[RFC1035_MAXNAMESIZE+1];
 
 #if	RFC1035_IPV6
 
-		if (IN6_IS_ADDR_V4MAPPED(sin))
-			memcpy(&in, (char *)sin + 12, 4);
+		if (IN6_IS_ADDR_V4MAPPED(addr))
+			memcpy(&in, (char *)addr + 12, 4);
 		else	return;
 #else
-		in= *sin;
+		in= *addr;
 #endif
 
 		he=gethostbyaddr( (char *)&in, sizeof(in), AF_INET);
