@@ -5,7 +5,7 @@
 ** Copyright 2000 Double Precision, Inc.
 ** See COPYING for distribution information.
 **
-** $Id: unicode.h,v 1.2 2000/10/07 19:04:10 mrsam Exp $
+** $Id: unicode.h,v 1.5 2000/12/24 03:26:43 mrsam Exp $
 */
 
 #ifdef	__cplusplus
@@ -107,6 +107,14 @@ extern char *unicode_convert(const char *txt,
 			     const struct unicode_info *to);
 	/* errno=EINVAL if conversion could not be performed */
 
+extern char *unicode_xconvert(const char *txt,
+			      const struct unicode_info *from,
+			      const struct unicode_info *to);
+	/* Like unicode_convert(), except unconvertable chars are replaced
+	** by periods (or something similar), instead of aborting with EINVAL
+	*/
+
+
 extern char *unicode_convert_fromchset(const char *txt,
 				    const char *from,
 				    const struct unicode_info *to);
@@ -115,6 +123,17 @@ extern char *unicode_convert_fromchset(const char *txt,
 	** errno=EINVAL if 'to' character set does not exist.
 	*/
 
+	/*
+	** Convert between unicode and modified-UTF7 encoding used for
+	** IMAP folder names.
+	*/
+
+unicode_char *unicode_modutf7touc(const char *s, int *err);
+
+	/* err < 0 if out of memory, else ptr to first illegal modutf7-char */
+	/* This can be used to test if string is a valid mod-utf7 string */
+
+char *unicode_uctomodutf7(const unicode_char *);
 
 #ifdef	__cplusplus
 }
